@@ -908,7 +908,8 @@ class CloudSQLDatabaseHook(BaseHook):
     def _set_temporary_ssl_file(
         self, cert_name: str, cert_path: str | None = None, cert_value: str | None = None
     ) -> str | None:
-        """Save the certificate as a temporary file.
+        """
+        Save the certificate as a temporary file.
 
         This method was implemented in order to overcome psql connection error caused by excessive file
         permissions: "private key file "..." has group or world access; file must have permissions
@@ -1019,7 +1020,8 @@ class CloudSQLDatabaseHook(BaseHook):
 
     @staticmethod
     def _generate_unique_path() -> str:
-        """Generate a unique path.
+        """
+        Generate a unique path.
 
         We don't using mkdtemp here since it can generate paths close to 60
         characters. We append project/location/instance to the path, Postgres
@@ -1106,7 +1108,8 @@ class CloudSQLDatabaseHook(BaseHook):
         return instance_specification
 
     def create_connection(self) -> Connection:
-        """Create a connection.
+        """
+        Create a connection.
 
         Connection ID will be randomly generated according to whether it uses
         proxy, TCP, UNIX sockets, SSL.
@@ -1117,7 +1120,8 @@ class CloudSQLDatabaseHook(BaseHook):
         return connection
 
     def get_sqlproxy_runner(self) -> CloudSqlProxyRunner:
-        """Retrieve Cloud SQL Proxy runner.
+        """
+        Retrieve Cloud SQL Proxy runner.
 
         It is used to manage the proxy lifecycle per task.
 
@@ -1137,7 +1141,8 @@ class CloudSQLDatabaseHook(BaseHook):
         )
 
     def get_database_hook(self, connection: Connection) -> PostgresHook | MySqlHook:
-        """Retrieve database hook.
+        """
+        Retrieve database hook.
 
         This is the actual Postgres or MySQL database hook that uses proxy or
         connects directly to the Google Cloud SQL database.
@@ -1168,7 +1173,8 @@ class CloudSQLDatabaseHook(BaseHook):
         self.sql_proxy_tcp_port = self.reserved_tcp_socket.getsockname()[1]
 
     def free_reserved_port(self) -> None:
-        """Free TCP port.
+        """
+        Free TCP port.
 
         Makes it immediately ready to be used by Cloud SQL Proxy.
         """
