@@ -147,7 +147,8 @@ class DataprocMetastoreDetailedLink(BaseOperatorLink):
 
 
 class DataprocMetastoreCreateBackupOperator(GoogleCloudBaseOperator):
-    """Create a new backup in a given project and location.
+    """
+    Create a new backup in a given project and location.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
@@ -261,7 +262,8 @@ class DataprocMetastoreCreateBackupOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreCreateMetadataImportOperator(GoogleCloudBaseOperator):
-    """Create a new MetadataImport in a given project and location.
+    """
+    Create a new MetadataImport in a given project and location.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
@@ -361,7 +363,8 @@ class DataprocMetastoreCreateMetadataImportOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreCreateServiceOperator(GoogleCloudBaseOperator):
-    """Create a metastore service in a project and location.
+    """
+    Create a metastore service in a project and location.
 
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
@@ -462,7 +465,8 @@ class DataprocMetastoreCreateServiceOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreDeleteBackupOperator(GoogleCloudBaseOperator):
-    """Delete a single backup.
+    """
+    Delete a single backup.
 
     :param project_id: Required. The ID of the Google Cloud project that the backup belongs to.
     :param region: Required. The ID of the Google Cloud region that the backup belongs to.
@@ -546,7 +550,8 @@ class DataprocMetastoreDeleteBackupOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreDeleteServiceOperator(GoogleCloudBaseOperator):
-    """Delete a single service.
+    """
+    Delete a single service.
 
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
@@ -614,7 +619,8 @@ class DataprocMetastoreDeleteServiceOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreExportMetadataOperator(GoogleCloudBaseOperator):
-    """Export metadata from a service.
+    """
+    Export metadata from a service.
 
     :param destination_gcs_folder: A Cloud Storage URI of a folder, in the format
         ``gs://<bucket_name>/<path_inside_bucket>``. A sub-folder
@@ -706,7 +712,8 @@ class DataprocMetastoreExportMetadataOperator(GoogleCloudBaseOperator):
         return destination_uri[5:] if destination_uri.startswith("gs://") else destination_uri
 
     def _wait_for_export_metadata(self, hook: DataprocMetastoreHook):
-        """Check that export was created successfully.
+        """
+        Check that export was created successfully.
 
         This is a workaround to an issue parsing result to MetadataExport inside
         the SDK.
@@ -732,7 +739,8 @@ class DataprocMetastoreExportMetadataOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreGetServiceOperator(GoogleCloudBaseOperator):
-    """Get the details of a single service.
+    """
+    Get the details of a single service.
 
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
@@ -804,7 +812,8 @@ class DataprocMetastoreGetServiceOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreListBackupsOperator(GoogleCloudBaseOperator):
-    """List backups in a service.
+    """
+    List backups in a service.
 
     :param project_id: Required. The ID of the Google Cloud project that the backup belongs to.
     :param region: Required. The ID of the Google Cloud region that the backup belongs to.
@@ -888,7 +897,8 @@ class DataprocMetastoreListBackupsOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreRestoreServiceOperator(GoogleCloudBaseOperator):
-    """Restore a service from a backup.
+    """
+    Restore a service from a backup.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
@@ -992,7 +1002,8 @@ class DataprocMetastoreRestoreServiceOperator(GoogleCloudBaseOperator):
         DataprocMetastoreLink.persist(context=context, task_instance=self, url=METASTORE_SERVICE_LINK)
 
     def _wait_for_restore_service(self, hook: DataprocMetastoreHook):
-        """Check that export was created successfully.
+        """
+        Check that export was created successfully.
 
         This is a workaround to an issue parsing result to MetadataExport inside
         the SDK.
@@ -1016,7 +1027,8 @@ class DataprocMetastoreRestoreServiceOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreUpdateServiceOperator(GoogleCloudBaseOperator):
-    """Update the parameters of a single service.
+    """
+    Update the parameters of a single service.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
